﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEngine.SceneManagement;
using System.IO;                                        // for working with files
using System.Runtime.Serialization.Formatters.Binary;   // RSFB helps Serialization

/// <summary>
/// Manages the important features like keeping the score, restarting levels,
/// saving/loading data, updating the HUD etc
/// </summary>
public class GameCtrl : MonoBehaviour
{
    public static GameCtrl instance;
    public float restartDelay;
    public GameData data;                       // to work with game data in the inspector

    string dataFilePath;                        // path to store the data file
    BinaryFormatter bf;                         // help in saving/loading to binary files


	void Awake()
	{
        if (instance == null)
            instance = this;

        bf = new BinaryFormatter();

        dataFilePath = Application.persistentDataPath + "/game.dat";
        Debug.Log(dataFilePath);
	}

	void Start()
	{
		
	}

	void Update()
	{
        if (Input.GetKeyDown(KeyCode.Escape))
            ResetData();
	}

    public void SaveData()
    {
        FileStream fs = new FileStream(dataFilePath, FileMode.Create);
        bf.Serialize(fs, data);
        fs.Close();
    }

    public void LoadData()
    {
        if(File.Exists(dataFilePath))
        {
            FileStream fs = new FileStream(dataFilePath, FileMode.Open);
            data = (GameData)bf.Deserialize(fs);
            Debug.Log("Number of Coins = " + data.coinCount);
            fs.Close();
        }
    }

    void ResetData()
    {
        FileStream fs = new FileStream(dataFilePath, FileMode.Create);
        data.coinCount = 0;
        bf.Serialize(fs, data);
        fs.Close();
        Debug.Log("Data Reset");
    }

	void OnEnable()
	{
		Debug.Log("Data Loaded");
        LoadData();
	}

    void OnDisable()
    {
        Debug.Log("Data Saved");
        SaveData();
    }

	/// <summary>
	/// called when the player dies
	/// </summary>
	public void PlayerDied(GameObject player)
    {
        player.SetActive(false);

        Invoke("RestartLevel", restartDelay);
    }

    /// <summary>
    /// called when the player falls in water
    /// </summary>
    public void PlayerDrowned(GameObject player)
    {
        Invoke("RestartLevel", restartDelay);
    }

    void RestartLevel()
    {
        SceneManager.LoadScene("Gameplay");
    }
}
